import json
import os
import requests

from cryptography.hazmat.primitives.asymmetric import rsa

from Mine.Block import Block
from Mine.Transaction import Transaction

WIKIDECK_URL = os.getenv('WIKIDECK_URL', 'http://localhost:8080/')

print("Generating RSA keys...")
privateKeyA = rsa.generate_private_key(
    public_exponent=65537,
    key_size=4096
    )
privateKeyB = rsa.generate_private_key(
    public_exponent=65537,
    key_size=4096
    )

print("Getting block to mine from server...")
newBlockA = Block(
    data = requests.get(f"{WIKIDECK_URL}/mine/blocks").json()
    )
print("Received block for user A to mine.")
print("Mining block...")
newBlockA.mine(privateKeyA)
r = requests.post(f"{WIKIDECK_URL}/mine/blocks", json=newBlockA.as_dict())
print(json.dumps(r.json(), indent=4))
input("Press enter to continue...")

print("Sending card A to user B...")
newTransaction = Transaction(
    cardId = newBlockA.card.cardId,
    sender = privateKeyA.public_key(),
    receiver = privateKeyB.public_key(),
    authorPrivateKey = privateKeyA
    )
r = requests.post(f"{WIKIDECK_URL}/mine/transactions", json=newTransaction.as_dict())
print(json.dumps(r.json(), indent=4))
input("Press enter to continue...")

print("Getting block to mine from server...")
newBlockB = Block(
    data = requests.get(f"{WIKIDECK_URL}/mine/blocks").json()
    )
print("Received block for user B to mine.")
print("Mining block...")
newBlockB.mine(privateKeyB)
r = requests.post(f"{WIKIDECK_URL}/mine/blocks", json=newBlockB.as_dict())
print(json.dumps(r.json(), indent=4))
